GetGridData
^^^^^^^^^^^

`GetGridData?Box=-35.035057,138.801484,-35.024338,138.82174 <https://www.waterconnect.sa.gov.au/_layouts/15/dfw.sharepoint.wdd/WDDDMS.ashx/GetGridData?Box=-35.035057,138.801484,-35.024338,138.82174>`__

Returns a JSON array of objects - only two are shown below:

.. code-block:: json

    [
      {
        "DHNO": 41267,
        "LAT": -35.0258564,
        "LON": 138.8098983,
        "MAPNUM": 662702847,
        "MAX_DEPTH": 4.5,
        "SWL": 0.7,
        "TDS": 655,
        "CLASS": "WW",
        "PWRA": "Western Mount Lofty Ranges",
        "NRM": "Adelaide & Mt Lofty Ranges",
        "LOGDRILL": "N",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "N",
        "STRATLOG": "N",
        "HSTRATLOG": "N",
        "LATEST_SWL_DATE": "1978-07-07",
        "LATEST_SAL_DATE": "1978-07-07",
        "LATEST_OPEN_DATE": "1978-07-07"
      },
      {
        "DHNO": 285207,
        "LAT": -35.0255666,
        "LON": 138.8127263,
        "MAPNUM": 662715026,
        "MAX_DEPTH": 77,
        "PERMIT_NO": 241236,
        "DRILL_DATE": "2015-04-14",
        "SWL": 3,
        "YIELD": 1.13,
        "TDS": 1821,
        "CLASS": "WW",
        "PWRA": "Western Mount Lofty Ranges",
        "NRM": "Adelaide & Mt Lofty Ranges",
        "LOGDRILL": "Y",
        "LITHOLOG": "N",
        "CHEM": "N",
        "WATER": "Y",
        "SAL": "Y",
        "OBSWELL": "N",
        "STRATLOG": "N",
        "HSTRATLOG": "N",
        "LATEST_SWL_DATE": "2015-04-14",
        "LATEST_SAL_DATE": "2015-04-14",
        "LATEST_YIELD_DATE": "2015-04-14",
        "LATEST_OPEN_DEPTH": 77,
        "LATEST_OPEN_DATE": "2015-04-14"
      }
    ]
